{
    "$graph": [
        {
            "class": "Workflow",
            "label": "HS Metrics workflow",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "type": "record",
                            "name": "#labelled_file.yml/labelled_file",
                            "label": "a file with a label",
                            "fields": [
                                {
                                    "type": "File",
                                    "name": "#labelled_file.yml/labelled_file/file"
                                },
                                {
                                    "type": "string",
                                    "name": "#labelled_file.yml/labelled_file/label"
                                }
                            ]
                        }
                    ]
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#hs_metrics.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#hs_metrics.cwl/minimum_base_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#hs_metrics.cwl/minimum_mapping_quality"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#labelled_file.yml/labelled_file"
                    },
                    "id": "#hs_metrics.cwl/per_base_intervals"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#labelled_file.yml/labelled_file"
                    },
                    "id": "#hs_metrics.cwl/per_target_intervals"
                },
                {
                    "type": "string",
                    "id": "#hs_metrics.cwl/reference"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#labelled_file.yml/labelled_file"
                    },
                    "id": "#hs_metrics.cwl/summary_intervals"
                }
            ],
            "steps": [
                {
                    "run": "#collect_hs_metrics.cwl",
                    "scatter": [
                        "#hs_metrics.cwl/collect_per_base_hs_metrics/bait_intervals",
                        "#hs_metrics.cwl/collect_per_base_hs_metrics/target_intervals",
                        "#hs_metrics.cwl/collect_per_base_hs_metrics/output_prefix"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#hs_metrics.cwl/per_base_intervals",
                            "valueFrom": "$(self.file)",
                            "id": "#hs_metrics.cwl/collect_per_base_hs_metrics/bait_intervals"
                        },
                        {
                            "source": "#hs_metrics.cwl/bam",
                            "id": "#hs_metrics.cwl/collect_per_base_hs_metrics/bam"
                        },
                        {
                            "valueFrom": "ALL_READS",
                            "id": "#hs_metrics.cwl/collect_per_base_hs_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#hs_metrics.cwl/minimum_base_quality",
                            "id": "#hs_metrics.cwl/collect_per_base_hs_metrics/minimum_base_quality"
                        },
                        {
                            "source": "#hs_metrics.cwl/minimum_mapping_quality",
                            "id": "#hs_metrics.cwl/collect_per_base_hs_metrics/minimum_mapping_quality"
                        },
                        {
                            "source": "#hs_metrics.cwl/per_base_intervals",
                            "valueFrom": "base-$(self.label)",
                            "id": "#hs_metrics.cwl/collect_per_base_hs_metrics/output_prefix"
                        },
                        {
                            "default": true,
                            "id": "#hs_metrics.cwl/collect_per_base_hs_metrics/per_base_coverage"
                        },
                        {
                            "default": false,
                            "id": "#hs_metrics.cwl/collect_per_base_hs_metrics/per_target_coverage"
                        },
                        {
                            "source": "#hs_metrics.cwl/reference",
                            "id": "#hs_metrics.cwl/collect_per_base_hs_metrics/reference"
                        },
                        {
                            "source": "#hs_metrics.cwl/per_base_intervals",
                            "valueFrom": "$(self.file)",
                            "id": "#hs_metrics.cwl/collect_per_base_hs_metrics/target_intervals"
                        }
                    ],
                    "out": [
                        "#hs_metrics.cwl/collect_per_base_hs_metrics/hs_metrics",
                        "#hs_metrics.cwl/collect_per_base_hs_metrics/per_base_coverage_metrics"
                    ],
                    "id": "#hs_metrics.cwl/collect_per_base_hs_metrics"
                },
                {
                    "run": "#collect_hs_metrics.cwl",
                    "scatter": [
                        "#hs_metrics.cwl/collect_per_target_hs_metrics/bait_intervals",
                        "#hs_metrics.cwl/collect_per_target_hs_metrics/target_intervals",
                        "#hs_metrics.cwl/collect_per_target_hs_metrics/output_prefix"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#hs_metrics.cwl/per_target_intervals",
                            "valueFrom": "$(self.file)",
                            "id": "#hs_metrics.cwl/collect_per_target_hs_metrics/bait_intervals"
                        },
                        {
                            "source": "#hs_metrics.cwl/bam",
                            "id": "#hs_metrics.cwl/collect_per_target_hs_metrics/bam"
                        },
                        {
                            "valueFrom": "ALL_READS",
                            "id": "#hs_metrics.cwl/collect_per_target_hs_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#hs_metrics.cwl/minimum_base_quality",
                            "id": "#hs_metrics.cwl/collect_per_target_hs_metrics/minimum_base_quality"
                        },
                        {
                            "source": "#hs_metrics.cwl/minimum_mapping_quality",
                            "id": "#hs_metrics.cwl/collect_per_target_hs_metrics/minimum_mapping_quality"
                        },
                        {
                            "source": "#hs_metrics.cwl/per_target_intervals",
                            "valueFrom": "target-$(self.label)",
                            "id": "#hs_metrics.cwl/collect_per_target_hs_metrics/output_prefix"
                        },
                        {
                            "default": false,
                            "id": "#hs_metrics.cwl/collect_per_target_hs_metrics/per_base_coverage"
                        },
                        {
                            "default": true,
                            "id": "#hs_metrics.cwl/collect_per_target_hs_metrics/per_target_coverage"
                        },
                        {
                            "source": "#hs_metrics.cwl/reference",
                            "id": "#hs_metrics.cwl/collect_per_target_hs_metrics/reference"
                        },
                        {
                            "source": "#hs_metrics.cwl/per_target_intervals",
                            "valueFrom": "$(self.file)",
                            "id": "#hs_metrics.cwl/collect_per_target_hs_metrics/target_intervals"
                        }
                    ],
                    "out": [
                        "#hs_metrics.cwl/collect_per_target_hs_metrics/hs_metrics",
                        "#hs_metrics.cwl/collect_per_target_hs_metrics/per_target_coverage_metrics"
                    ],
                    "id": "#hs_metrics.cwl/collect_per_target_hs_metrics"
                },
                {
                    "run": "#collect_hs_metrics.cwl",
                    "scatter": [
                        "#hs_metrics.cwl/collect_summary_hs_metrics/bait_intervals",
                        "#hs_metrics.cwl/collect_summary_hs_metrics/target_intervals",
                        "#hs_metrics.cwl/collect_summary_hs_metrics/output_prefix"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#hs_metrics.cwl/summary_intervals",
                            "valueFrom": "$(self.file)",
                            "id": "#hs_metrics.cwl/collect_summary_hs_metrics/bait_intervals"
                        },
                        {
                            "source": "#hs_metrics.cwl/bam",
                            "id": "#hs_metrics.cwl/collect_summary_hs_metrics/bam"
                        },
                        {
                            "valueFrom": "ALL_READS",
                            "id": "#hs_metrics.cwl/collect_summary_hs_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#hs_metrics.cwl/minimum_base_quality",
                            "id": "#hs_metrics.cwl/collect_summary_hs_metrics/minimum_base_quality"
                        },
                        {
                            "source": "#hs_metrics.cwl/minimum_mapping_quality",
                            "id": "#hs_metrics.cwl/collect_summary_hs_metrics/minimum_mapping_quality"
                        },
                        {
                            "source": "#hs_metrics.cwl/summary_intervals",
                            "valueFrom": "summary-$(self.label)",
                            "id": "#hs_metrics.cwl/collect_summary_hs_metrics/output_prefix"
                        },
                        {
                            "default": false,
                            "id": "#hs_metrics.cwl/collect_summary_hs_metrics/per_base_coverage"
                        },
                        {
                            "default": false,
                            "id": "#hs_metrics.cwl/collect_summary_hs_metrics/per_target_coverage"
                        },
                        {
                            "source": "#hs_metrics.cwl/reference",
                            "id": "#hs_metrics.cwl/collect_summary_hs_metrics/reference"
                        },
                        {
                            "source": "#hs_metrics.cwl/summary_intervals",
                            "valueFrom": "$(self.file)",
                            "id": "#hs_metrics.cwl/collect_summary_hs_metrics/target_intervals"
                        }
                    ],
                    "out": [
                        "#hs_metrics.cwl/collect_summary_hs_metrics/hs_metrics"
                    ],
                    "id": "#hs_metrics.cwl/collect_summary_hs_metrics"
                }
            ],
            "id": "#hs_metrics.cwl",
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#hs_metrics.cwl/collect_per_base_hs_metrics/per_base_coverage_metrics",
                    "id": "#hs_metrics.cwl/per_base_coverage_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#hs_metrics.cwl/collect_per_base_hs_metrics/hs_metrics",
                    "id": "#hs_metrics.cwl/per_base_hs_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#hs_metrics.cwl/collect_per_target_hs_metrics/per_target_coverage_metrics",
                    "id": "#hs_metrics.cwl/per_target_coverage_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#hs_metrics.cwl/collect_per_target_hs_metrics/hs_metrics",
                    "id": "#hs_metrics.cwl/per_target_hs_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#hs_metrics.cwl/collect_summary_hs_metrics/hs_metrics",
                    "id": "#hs_metrics.cwl/summary_hs_metrics"
                }
            ]
        },
        {
            "class": "Workflow",
            "label": "umi molecular alignment workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#molecular_alignment.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.1,
                    "id": "#molecular_alignment.cwl/max_base_error_rate"
                },
                {
                    "type": "float",
                    "default": 0.5,
                    "id": "#molecular_alignment.cwl/max_no_call_fraction"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.05,
                    "id": "#molecular_alignment.cwl/max_read_error_rate"
                },
                {
                    "type": "int",
                    "default": 1,
                    "id": "#molecular_alignment.cwl/min_base_quality"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "int"
                    },
                    "default": [
                        1
                    ],
                    "id": "#molecular_alignment.cwl/min_reads"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#molecular_alignment.cwl/read_structure"
                },
                {
                    "type": "string",
                    "id": "#molecular_alignment.cwl/reference"
                },
                {
                    "type": "string",
                    "id": "#molecular_alignment.cwl/sample_name"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#molecular_alignment.cwl/target_intervals"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#molecular_alignment.cwl/align/adapter_metrics",
                    "id": "#molecular_alignment.cwl/adapter_histogram"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai",
                        "^.bai"
                    ],
                    "outputSource": "#molecular_alignment.cwl/index_bam/indexed_bam",
                    "id": "#molecular_alignment.cwl/aligned_bam"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#molecular_alignment.cwl/collect_duplex_seq_metrics/duplex_seq_metrics",
                    "id": "#molecular_alignment.cwl/duplex_seq_metrics"
                }
            ],
            "steps": [
                {
                    "scatter": "#molecular_alignment.cwl/align/bam",
                    "run": "#umi_alignment.cwl",
                    "in": [
                        {
                            "source": "#molecular_alignment.cwl/bam",
                            "id": "#molecular_alignment.cwl/align/bam"
                        },
                        {
                            "source": "#molecular_alignment.cwl/read_structure",
                            "id": "#molecular_alignment.cwl/align/read_structure"
                        },
                        {
                            "source": "#molecular_alignment.cwl/reference",
                            "id": "#molecular_alignment.cwl/align/reference"
                        }
                    ],
                    "out": [
                        "#molecular_alignment.cwl/align/aligned_bam",
                        "#molecular_alignment.cwl/align/adapter_metrics"
                    ],
                    "id": "#molecular_alignment.cwl/align"
                },
                {
                    "run": "#realign.cwl",
                    "in": [
                        {
                            "source": "#molecular_alignment.cwl/call_molecular_consensus/consensus_bam",
                            "id": "#molecular_alignment.cwl/align_consensus/bam"
                        },
                        {
                            "source": "#molecular_alignment.cwl/reference",
                            "id": "#molecular_alignment.cwl/align_consensus/reference"
                        }
                    ],
                    "out": [
                        "#molecular_alignment.cwl/align_consensus/consensus_aligned_bam"
                    ],
                    "id": "#molecular_alignment.cwl/align_consensus"
                },
                {
                    "run": "#call_molecular_consensus.cwl",
                    "in": [
                        {
                            "source": "#molecular_alignment.cwl/group_reads_by_umi/grouped_bam",
                            "id": "#molecular_alignment.cwl/call_molecular_consensus/bam"
                        }
                    ],
                    "out": [
                        "#molecular_alignment.cwl/call_molecular_consensus/consensus_bam"
                    ],
                    "id": "#molecular_alignment.cwl/call_molecular_consensus"
                },
                {
                    "run": "#clip_overlap.cwl",
                    "in": [
                        {
                            "source": "#molecular_alignment.cwl/filter_consensus/filtered_bam",
                            "id": "#molecular_alignment.cwl/clip_overlap/bam"
                        },
                        {
                            "source": "#molecular_alignment.cwl/reference",
                            "id": "#molecular_alignment.cwl/clip_overlap/reference"
                        }
                    ],
                    "out": [
                        "#molecular_alignment.cwl/clip_overlap/clipped_bam"
                    ],
                    "id": "#molecular_alignment.cwl/clip_overlap"
                },
                {
                    "run": "#duplex_seq_metrics.cwl",
                    "in": [
                        {
                            "source": "#molecular_alignment.cwl/group_reads_by_umi/grouped_bam",
                            "id": "#molecular_alignment.cwl/collect_duplex_seq_metrics/bam"
                        },
                        {
                            "source": "#molecular_alignment.cwl/sample_name",
                            "id": "#molecular_alignment.cwl/collect_duplex_seq_metrics/description"
                        },
                        {
                            "source": "#molecular_alignment.cwl/target_intervals",
                            "id": "#molecular_alignment.cwl/collect_duplex_seq_metrics/intervals"
                        }
                    ],
                    "out": [
                        "#molecular_alignment.cwl/collect_duplex_seq_metrics/duplex_seq_metrics"
                    ],
                    "id": "#molecular_alignment.cwl/collect_duplex_seq_metrics"
                },
                {
                    "run": "#filter_consensus.cwl",
                    "in": [
                        {
                            "source": "#molecular_alignment.cwl/align_consensus/consensus_aligned_bam",
                            "id": "#molecular_alignment.cwl/filter_consensus/bam"
                        },
                        {
                            "source": "#molecular_alignment.cwl/max_base_error_rate",
                            "id": "#molecular_alignment.cwl/filter_consensus/max_base_error_rate"
                        },
                        {
                            "source": "#molecular_alignment.cwl/max_no_call_fraction",
                            "id": "#molecular_alignment.cwl/filter_consensus/max_no_call_fraction"
                        },
                        {
                            "source": "#molecular_alignment.cwl/max_read_error_rate",
                            "id": "#molecular_alignment.cwl/filter_consensus/max_read_error_rate"
                        },
                        {
                            "source": "#molecular_alignment.cwl/min_base_quality",
                            "id": "#molecular_alignment.cwl/filter_consensus/min_base_quality"
                        },
                        {
                            "source": "#molecular_alignment.cwl/min_reads",
                            "id": "#molecular_alignment.cwl/filter_consensus/min_reads"
                        },
                        {
                            "source": "#molecular_alignment.cwl/reference",
                            "id": "#molecular_alignment.cwl/filter_consensus/reference"
                        }
                    ],
                    "out": [
                        "#molecular_alignment.cwl/filter_consensus/filtered_bam"
                    ],
                    "id": "#molecular_alignment.cwl/filter_consensus"
                },
                {
                    "run": "#group_reads.cwl",
                    "in": [
                        {
                            "source": "#molecular_alignment.cwl/merge/merged_bam",
                            "id": "#molecular_alignment.cwl/group_reads_by_umi/bam"
                        }
                    ],
                    "out": [
                        "#molecular_alignment.cwl/group_reads_by_umi/grouped_bam"
                    ],
                    "id": "#molecular_alignment.cwl/group_reads_by_umi"
                },
                {
                    "run": "#index_bam.cwl",
                    "in": [
                        {
                            "source": "#molecular_alignment.cwl/clip_overlap/clipped_bam",
                            "id": "#molecular_alignment.cwl/index_bam/bam"
                        }
                    ],
                    "out": [
                        "#molecular_alignment.cwl/index_bam/indexed_bam"
                    ],
                    "id": "#molecular_alignment.cwl/index_bam"
                },
                {
                    "run": "#merge_bams.cwl",
                    "in": [
                        {
                            "source": "#molecular_alignment.cwl/align/aligned_bam",
                            "id": "#molecular_alignment.cwl/merge/bams"
                        }
                    ],
                    "out": [
                        "#molecular_alignment.cwl/merge/merged_bam"
                    ],
                    "id": "#molecular_alignment.cwl/merge"
                }
            ],
            "id": "#molecular_alignment.cwl"
        },
        {
            "class": "Workflow",
            "label": "umi molecular alignment workflow",
            "requirements": [
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#labelled_file.yml/labelled_file"
                        }
                    ]
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/bait_intervals"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/bam"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/minimum_base_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/minimum_mapping_quality"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/omni_vcf"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#labelled_file.yml/labelled_file"
                    },
                    "id": "#main/per_base_intervals"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#labelled_file.yml/labelled_file"
                    },
                    "id": "#main/per_target_intervals"
                },
                {
                    "type": "string",
                    "id": "#main/picard_metric_accumulation_level"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/read_structure"
                },
                {
                    "type": "string",
                    "id": "#main/reference"
                },
                {
                    "type": "string",
                    "id": "#main/sample_name"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#labelled_file.yml/labelled_file"
                    },
                    "id": "#main/summary_intervals"
                },
                {
                    "type": "File",
                    "id": "#main/target_intervals"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/alignment/adapter_histogram",
                    "id": "#main/adapter_histogram"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai",
                        "^.bai"
                    ],
                    "outputSource": "#main/alignment/aligned_bam",
                    "id": "#main/aligned_bam"
                },
                {
                    "type": "File",
                    "outputSource": "#main/qc/alignment_summary_metrics",
                    "id": "#main/alignment_summary_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/alignment/duplex_seq_metrics",
                    "id": "#main/duplex_seq_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/qc/flagstats",
                    "id": "#main/flagstats"
                },
                {
                    "type": "File",
                    "outputSource": "#main/qc/hs_metrics",
                    "id": "#main/hs_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/qc/insert_size_histogram",
                    "id": "#main/insert_size_histogram"
                },
                {
                    "type": "File",
                    "outputSource": "#main/qc/insert_size_metrics",
                    "id": "#main/insert_size_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/qc/per_base_coverage_metrics",
                    "id": "#main/per_base_coverage_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/qc/per_base_hs_metrics",
                    "id": "#main/per_base_hs_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/qc/per_target_coverage_metrics",
                    "id": "#main/per_target_coverage_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/qc/per_target_hs_metrics",
                    "id": "#main/per_target_hs_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/qc/summary_hs_metrics",
                    "id": "#main/summary_hs_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/qc/verify_bam_id_depth",
                    "id": "#main/verify_bam_id_depth"
                },
                {
                    "type": "File",
                    "outputSource": "#main/qc/verify_bam_id_metrics",
                    "id": "#main/verify_bam_id_metrics"
                }
            ],
            "steps": [
                {
                    "run": "#molecular_alignment.cwl",
                    "in": [
                        {
                            "source": "#main/bam",
                            "id": "#main/alignment/bam"
                        },
                        {
                            "source": "#main/read_structure",
                            "id": "#main/alignment/read_structure"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/alignment/reference"
                        },
                        {
                            "source": "#main/sample_name",
                            "id": "#main/alignment/sample_name"
                        },
                        {
                            "source": "#main/target_intervals",
                            "id": "#main/alignment/target_intervals"
                        }
                    ],
                    "out": [
                        "#main/alignment/aligned_bam",
                        "#main/alignment/adapter_histogram",
                        "#main/alignment/duplex_seq_metrics"
                    ],
                    "id": "#main/alignment"
                },
                {
                    "run": "#qc_exome.cwl",
                    "in": [
                        {
                            "source": "#main/bait_intervals",
                            "id": "#main/qc/bait_intervals"
                        },
                        {
                            "source": "#main/alignment/aligned_bam",
                            "id": "#main/qc/bam"
                        },
                        {
                            "source": "#main/minimum_base_quality",
                            "id": "#main/qc/minimum_base_quality"
                        },
                        {
                            "source": "#main/minimum_mapping_quality",
                            "id": "#main/qc/minimum_mapping_quality"
                        },
                        {
                            "source": "#main/omni_vcf",
                            "id": "#main/qc/omni_vcf"
                        },
                        {
                            "source": "#main/per_base_intervals",
                            "id": "#main/qc/per_base_intervals"
                        },
                        {
                            "source": "#main/per_target_intervals",
                            "id": "#main/qc/per_target_intervals"
                        },
                        {
                            "source": "#main/picard_metric_accumulation_level",
                            "id": "#main/qc/picard_metric_accumulation_level"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/qc/reference"
                        },
                        {
                            "source": "#main/summary_intervals",
                            "id": "#main/qc/summary_intervals"
                        },
                        {
                            "source": "#main/target_intervals",
                            "id": "#main/qc/target_intervals"
                        }
                    ],
                    "out": [
                        "#main/qc/insert_size_metrics",
                        "#main/qc/insert_size_histogram",
                        "#main/qc/alignment_summary_metrics",
                        "#main/qc/hs_metrics",
                        "#main/qc/per_target_coverage_metrics",
                        "#main/qc/per_target_hs_metrics",
                        "#main/qc/per_base_coverage_metrics",
                        "#main/qc/per_base_hs_metrics",
                        "#main/qc/summary_hs_metrics",
                        "#main/qc/flagstats",
                        "#main/qc/verify_bam_id_metrics",
                        "#main/qc/verify_bam_id_depth"
                    ],
                    "id": "#main/qc"
                }
            ],
            "id": "#main"
        },
        {
            "class": "Workflow",
            "label": "Exome QC workflow",
            "requirements": [
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#labelled_file.yml/labelled_file"
                        }
                    ]
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#qc_exome.cwl/bait_intervals"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#qc_exome.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#qc_exome.cwl/minimum_base_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#qc_exome.cwl/minimum_mapping_quality"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#qc_exome.cwl/omni_vcf"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#labelled_file.yml/labelled_file"
                    },
                    "id": "#qc_exome.cwl/per_base_intervals"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#labelled_file.yml/labelled_file"
                    },
                    "id": "#qc_exome.cwl/per_target_intervals"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "ALL_READS",
                    "id": "#qc_exome.cwl/picard_metric_accumulation_level"
                },
                {
                    "type": "string",
                    "id": "#qc_exome.cwl/reference"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#labelled_file.yml/labelled_file"
                    },
                    "id": "#qc_exome.cwl/summary_intervals"
                },
                {
                    "type": "File",
                    "id": "#qc_exome.cwl/target_intervals"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#qc_exome.cwl/collect_alignment_summary_metrics/alignment_summary_metrics",
                    "id": "#qc_exome.cwl/alignment_summary_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#qc_exome.cwl/samtools_flagstat/flagstats",
                    "id": "#qc_exome.cwl/flagstats"
                },
                {
                    "type": "File",
                    "outputSource": "#qc_exome.cwl/collect_roi_hs_metrics/hs_metrics",
                    "id": "#qc_exome.cwl/hs_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#qc_exome.cwl/collect_insert_size_metrics/insert_size_histogram",
                    "id": "#qc_exome.cwl/insert_size_histogram"
                },
                {
                    "type": "File",
                    "outputSource": "#qc_exome.cwl/collect_insert_size_metrics/insert_size_metrics",
                    "id": "#qc_exome.cwl/insert_size_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#qc_exome.cwl/collect_detailed_hs_metrics/per_base_coverage_metrics",
                    "id": "#qc_exome.cwl/per_base_coverage_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#qc_exome.cwl/collect_detailed_hs_metrics/per_base_hs_metrics",
                    "id": "#qc_exome.cwl/per_base_hs_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#qc_exome.cwl/collect_detailed_hs_metrics/per_target_coverage_metrics",
                    "id": "#qc_exome.cwl/per_target_coverage_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#qc_exome.cwl/collect_detailed_hs_metrics/per_target_hs_metrics",
                    "id": "#qc_exome.cwl/per_target_hs_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#qc_exome.cwl/collect_detailed_hs_metrics/summary_hs_metrics",
                    "id": "#qc_exome.cwl/summary_hs_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#qc_exome.cwl/verify_bam_id/verify_bam_id_depth",
                    "id": "#qc_exome.cwl/verify_bam_id_depth"
                },
                {
                    "type": "File",
                    "outputSource": "#qc_exome.cwl/verify_bam_id/verify_bam_id_metrics",
                    "id": "#qc_exome.cwl/verify_bam_id_metrics"
                }
            ],
            "steps": [
                {
                    "run": "#collect_alignment_summary_metrics.cwl",
                    "in": [
                        {
                            "source": "#qc_exome.cwl/bam",
                            "id": "#qc_exome.cwl/collect_alignment_summary_metrics/bam"
                        },
                        {
                            "source": "#qc_exome.cwl/picard_metric_accumulation_level",
                            "id": "#qc_exome.cwl/collect_alignment_summary_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#qc_exome.cwl/reference",
                            "id": "#qc_exome.cwl/collect_alignment_summary_metrics/reference"
                        }
                    ],
                    "out": [
                        "#qc_exome.cwl/collect_alignment_summary_metrics/alignment_summary_metrics"
                    ],
                    "id": "#qc_exome.cwl/collect_alignment_summary_metrics"
                },
                {
                    "run": "#hs_metrics.cwl",
                    "in": [
                        {
                            "source": "#qc_exome.cwl/bam",
                            "id": "#qc_exome.cwl/collect_detailed_hs_metrics/bam"
                        },
                        {
                            "source": "#qc_exome.cwl/minimum_base_quality",
                            "id": "#qc_exome.cwl/collect_detailed_hs_metrics/minimum_base_quality"
                        },
                        {
                            "source": "#qc_exome.cwl/minimum_mapping_quality",
                            "id": "#qc_exome.cwl/collect_detailed_hs_metrics/minimum_mapping_quality"
                        },
                        {
                            "source": "#qc_exome.cwl/per_base_intervals",
                            "id": "#qc_exome.cwl/collect_detailed_hs_metrics/per_base_intervals"
                        },
                        {
                            "source": "#qc_exome.cwl/per_target_intervals",
                            "id": "#qc_exome.cwl/collect_detailed_hs_metrics/per_target_intervals"
                        },
                        {
                            "source": "#qc_exome.cwl/reference",
                            "id": "#qc_exome.cwl/collect_detailed_hs_metrics/reference"
                        },
                        {
                            "source": "#qc_exome.cwl/summary_intervals",
                            "id": "#qc_exome.cwl/collect_detailed_hs_metrics/summary_intervals"
                        }
                    ],
                    "out": [
                        "#qc_exome.cwl/collect_detailed_hs_metrics/per_base_coverage_metrics",
                        "#qc_exome.cwl/collect_detailed_hs_metrics/per_base_hs_metrics",
                        "#qc_exome.cwl/collect_detailed_hs_metrics/per_target_coverage_metrics",
                        "#qc_exome.cwl/collect_detailed_hs_metrics/per_target_hs_metrics",
                        "#qc_exome.cwl/collect_detailed_hs_metrics/summary_hs_metrics"
                    ],
                    "id": "#qc_exome.cwl/collect_detailed_hs_metrics"
                },
                {
                    "run": "#collect_insert_size_metrics.cwl",
                    "in": [
                        {
                            "source": "#qc_exome.cwl/bam",
                            "id": "#qc_exome.cwl/collect_insert_size_metrics/bam"
                        },
                        {
                            "source": "#qc_exome.cwl/picard_metric_accumulation_level",
                            "id": "#qc_exome.cwl/collect_insert_size_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#qc_exome.cwl/reference",
                            "id": "#qc_exome.cwl/collect_insert_size_metrics/reference"
                        }
                    ],
                    "out": [
                        "#qc_exome.cwl/collect_insert_size_metrics/insert_size_metrics",
                        "#qc_exome.cwl/collect_insert_size_metrics/insert_size_histogram"
                    ],
                    "id": "#qc_exome.cwl/collect_insert_size_metrics"
                },
                {
                    "run": "#collect_hs_metrics.cwl",
                    "in": [
                        {
                            "source": "#qc_exome.cwl/bait_intervals",
                            "id": "#qc_exome.cwl/collect_roi_hs_metrics/bait_intervals"
                        },
                        {
                            "source": "#qc_exome.cwl/bam",
                            "id": "#qc_exome.cwl/collect_roi_hs_metrics/bam"
                        },
                        {
                            "valueFrom": "ALL_READS",
                            "id": "#qc_exome.cwl/collect_roi_hs_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#qc_exome.cwl/minimum_base_quality",
                            "id": "#qc_exome.cwl/collect_roi_hs_metrics/minimum_base_quality"
                        },
                        {
                            "source": "#qc_exome.cwl/minimum_mapping_quality",
                            "id": "#qc_exome.cwl/collect_roi_hs_metrics/minimum_mapping_quality"
                        },
                        {
                            "valueFrom": "roi",
                            "id": "#qc_exome.cwl/collect_roi_hs_metrics/output_prefix"
                        },
                        {
                            "default": false,
                            "id": "#qc_exome.cwl/collect_roi_hs_metrics/per_base_coverage"
                        },
                        {
                            "default": false,
                            "id": "#qc_exome.cwl/collect_roi_hs_metrics/per_target_coverage"
                        },
                        {
                            "source": "#qc_exome.cwl/reference",
                            "id": "#qc_exome.cwl/collect_roi_hs_metrics/reference"
                        },
                        {
                            "source": "#qc_exome.cwl/target_intervals",
                            "id": "#qc_exome.cwl/collect_roi_hs_metrics/target_intervals"
                        }
                    ],
                    "out": [
                        "#qc_exome.cwl/collect_roi_hs_metrics/hs_metrics"
                    ],
                    "id": "#qc_exome.cwl/collect_roi_hs_metrics"
                },
                {
                    "run": "#samtools_flagstat.cwl",
                    "in": [
                        {
                            "source": "#qc_exome.cwl/bam",
                            "id": "#qc_exome.cwl/samtools_flagstat/bam"
                        }
                    ],
                    "out": [
                        "#qc_exome.cwl/samtools_flagstat/flagstats"
                    ],
                    "id": "#qc_exome.cwl/samtools_flagstat"
                },
                {
                    "run": "#select_variants.cwl",
                    "in": [
                        {
                            "source": "#qc_exome.cwl/target_intervals",
                            "id": "#qc_exome.cwl/select_variants/interval_list"
                        },
                        {
                            "source": "#qc_exome.cwl/reference",
                            "id": "#qc_exome.cwl/select_variants/reference"
                        },
                        {
                            "source": "#qc_exome.cwl/omni_vcf",
                            "id": "#qc_exome.cwl/select_variants/vcf"
                        }
                    ],
                    "out": [
                        "#qc_exome.cwl/select_variants/filtered_vcf"
                    ],
                    "id": "#qc_exome.cwl/select_variants"
                },
                {
                    "run": "#verify_bam_id.cwl",
                    "in": [
                        {
                            "source": "#qc_exome.cwl/bam",
                            "id": "#qc_exome.cwl/verify_bam_id/bam"
                        },
                        {
                            "source": "#qc_exome.cwl/select_variants/filtered_vcf",
                            "id": "#qc_exome.cwl/verify_bam_id/vcf"
                        }
                    ],
                    "out": [
                        "#qc_exome.cwl/verify_bam_id/verify_bam_id_metrics",
                        "#qc_exome.cwl/verify_bam_id/verify_bam_id_depth"
                    ],
                    "id": "#qc_exome.cwl/verify_bam_id"
                }
            ],
            "id": "#qc_exome.cwl"
        },
        {
            "class": "Workflow",
            "label": "umi per-lane alignment subworkflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#umi_alignment.cwl/bam"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#umi_alignment.cwl/read_structure"
                },
                {
                    "type": "string",
                    "id": "#umi_alignment.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#umi_alignment.cwl/mark_illumina_adapters/metrics",
                    "id": "#umi_alignment.cwl/adapter_metrics"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "outputSource": "#umi_alignment.cwl/align/aligned_bam",
                    "id": "#umi_alignment.cwl/aligned_bam"
                }
            ],
            "steps": [
                {
                    "run": "#umi_align.cwl",
                    "in": [
                        {
                            "source": "#umi_alignment.cwl/mark_illumina_adapters/marked_bam",
                            "id": "#umi_alignment.cwl/align/bam"
                        },
                        {
                            "source": "#umi_alignment.cwl/reference",
                            "id": "#umi_alignment.cwl/align/reference"
                        }
                    ],
                    "out": [
                        "#umi_alignment.cwl/align/aligned_bam"
                    ],
                    "id": "#umi_alignment.cwl/align"
                },
                {
                    "run": "#extract_umis.cwl",
                    "in": [
                        {
                            "source": "#umi_alignment.cwl/bam",
                            "id": "#umi_alignment.cwl/extract_umis/bam"
                        },
                        {
                            "source": "#umi_alignment.cwl/read_structure",
                            "id": "#umi_alignment.cwl/extract_umis/read_structure"
                        }
                    ],
                    "out": [
                        "#umi_alignment.cwl/extract_umis/umi_extracted_bam"
                    ],
                    "id": "#umi_alignment.cwl/extract_umis"
                },
                {
                    "run": "#mark_illumina_adapters.cwl",
                    "in": [
                        {
                            "source": "#umi_alignment.cwl/extract_umis/umi_extracted_bam",
                            "id": "#umi_alignment.cwl/mark_illumina_adapters/bam"
                        }
                    ],
                    "out": [
                        "#umi_alignment.cwl/mark_illumina_adapters/marked_bam",
                        "#umi_alignment.cwl/mark_illumina_adapters/metrics"
                    ],
                    "id": "#umi_alignment.cwl/mark_illumina_adapters"
                }
            ],
            "id": "#umi_alignment.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "call molecular consensus",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/fgbio-0.5.0.jar",
                "CallMolecularConsensusReads"
            ],
            "arguments": [
                "--error-rate-pre-umi",
                "45",
                "--error-rate-post-umi",
                "30",
                "--min-input-base-quality",
                "30",
                "--min-reads",
                "1",
                "--output",
                {
                    "valueFrom": "$(runtime.outdir)/consensus_unaligned.bam"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/dna-alignment"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--input"
                    },
                    "id": "#call_molecular_consensus.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "consensus_unaligned.bam"
                    },
                    "id": "#call_molecular_consensus.cwl/consensus_bam"
                }
            ],
            "id": "#call_molecular_consensus.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "clip overlapping reads",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/fgbio-0.5.0.jar",
                "ClipBam"
            ],
            "arguments": [
                "--soft-clip",
                "false",
                "--clip-overlapping-reads",
                "true",
                "--output",
                {
                    "valueFrom": "$(runtime.outdir)/clipped.bam"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/dna-alignment"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--input"
                    },
                    "id": "#clip_overlap.cwl/bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--ref"
                    },
                    "id": "#clip_overlap.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "clipped.bam"
                    },
                    "id": "#clip_overlap.cwl/clipped_bam"
                }
            ],
            "id": "#clip_overlap.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "collect alignment summary metrics",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/usr/picard/picard.jar",
                "CollectAlignmentSummaryMetrics"
            ],
            "arguments": [
                "OUTPUT=",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.bam.nameroot).AlignmentSummaryMetrics.txt"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 18000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/picard-cwl:2.18.1"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "INPUT="
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#collect_alignment_summary_metrics.cwl/bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "METRIC_ACCUMULATION_LEVEL="
                    },
                    "id": "#collect_alignment_summary_metrics.cwl/metric_accumulation_level"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "REFERENCE_SEQUENCE="
                    },
                    "id": "#collect_alignment_summary_metrics.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot).AlignmentSummaryMetrics.txt"
                    },
                    "id": "#collect_alignment_summary_metrics.cwl/alignment_summary_metrics"
                }
            ],
            "id": "#collect_alignment_summary_metrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "collect HS metrics",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx48g",
                "-jar",
                "/usr/picard/picard.jar",
                "CollectHsMetrics"
            ],
            "arguments": [
                "O=",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.bam.nameroot).$(inputs.output_prefix)-HsMetrics.txt"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 52000
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/picard-cwl:2.18.1"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "BAIT_INTERVALS="
                    },
                    "id": "#collect_hs_metrics.cwl/bait_intervals"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "I="
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#collect_hs_metrics.cwl/bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "METRIC_ACCUMULATION_LEVEL="
                    },
                    "id": "#collect_hs_metrics.cwl/metric_accumulation_level"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 1,
                    "inputBinding": {
                        "prefix": "MINIMUM_BASE_QUALITY="
                    },
                    "id": "#collect_hs_metrics.cwl/minimum_base_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 1,
                    "inputBinding": {
                        "prefix": "MINIMUM_MAPPING_QUALITY="
                    },
                    "id": "#collect_hs_metrics.cwl/minimum_mapping_quality"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "out",
                    "id": "#collect_hs_metrics.cwl/output_prefix"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "PER_BASE_COVERAGE=",
                        "valueFrom": "${\n    if(self) {\n        return inputs.bam.nameroot + \".\" + inputs.output_prefix + \"-PerBaseCoverage.txt\"\n    } else {\n        return false;\n    }\n}\n"
                    },
                    "id": "#collect_hs_metrics.cwl/per_base_coverage"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "PER_TARGET_COVERAGE=",
                        "valueFrom": "${\n    if(self) {\n        return inputs.bam.nameroot + \".\" + inputs.output_prefix + \"-PerTargetCoverage.txt\"\n    } else {\n        return false;\n    }\n}\n"
                    },
                    "id": "#collect_hs_metrics.cwl/per_target_coverage"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "R="
                    },
                    "id": "#collect_hs_metrics.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "TARGET_INTERVALS="
                    },
                    "id": "#collect_hs_metrics.cwl/target_intervals"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot).$(inputs.output_prefix)-HsMetrics.txt"
                    },
                    "id": "#collect_hs_metrics.cwl/hs_metrics"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot).$(inputs.output_prefix)-PerBaseCoverage.txt"
                    },
                    "id": "#collect_hs_metrics.cwl/per_base_coverage_metrics"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot).$(inputs.output_prefix)-PerTargetCoverage.txt"
                    },
                    "id": "#collect_hs_metrics.cwl/per_target_coverage_metrics"
                }
            ],
            "id": "#collect_hs_metrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "collect insert size metrics",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/usr/picard/picard.jar",
                "CollectInsertSizeMetrics"
            ],
            "arguments": [
                "O=",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.bam.nameroot).InsertSizeMetrics.txt"
                },
                "H=",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.bam.nameroot).InsertSizeHistogram.pdf"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 18000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/picard-cwl:2.18.1"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "I="
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#collect_insert_size_metrics.cwl/bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "METRIC_ACCUMULATION_LEVEL="
                    },
                    "id": "#collect_insert_size_metrics.cwl/metric_accumulation_level"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "REFERENCE_SEQUENCE="
                    },
                    "id": "#collect_insert_size_metrics.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot).InsertSizeHistogram.pdf"
                    },
                    "id": "#collect_insert_size_metrics.cwl/insert_size_histogram"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot).InsertSizeMetrics.txt"
                    },
                    "id": "#collect_insert_size_metrics.cwl/insert_size_metrics"
                }
            ],
            "id": "#collect_insert_size_metrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "collect duplex seq metrics",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/fgbio-0.5.0.jar",
                "CollectDuplexSeqMetrics"
            ],
            "arguments": [
                "--output",
                {
                    "valueFrom": "$(runtime.outdir)/duplex_seq.metrics"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 1000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/dna-alignment"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--input"
                    },
                    "id": "#duplex_seq_metrics.cwl/bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--description"
                    },
                    "id": "#duplex_seq_metrics.cwl/description"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--intervals"
                    },
                    "id": "#duplex_seq_metrics.cwl/intervals"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "duplex_seq.metrics.*"
                    },
                    "id": "#duplex_seq_metrics.cwl/duplex_seq_metrics"
                }
            ],
            "id": "#duplex_seq_metrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "extract umis from bam",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/fgbio-0.5.0.jar",
                "ExtractUmisFromBam"
            ],
            "arguments": [
                "--molecular-index-tags",
                "ZA",
                "ZB",
                "--single-tag",
                "RX",
                "--output",
                {
                    "valueFrom": "$(runtime.outdir)/umi_extracted.bam"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/dna-alignment"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--input"
                    },
                    "id": "#extract_umis.cwl/bam"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "inputBinding": {
                        "prefix": "--read-structure"
                    },
                    "id": "#extract_umis.cwl/read_structure"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "umi_extracted.bam"
                    },
                    "id": "#extract_umis.cwl/umi_extracted_bam"
                }
            ],
            "id": "#extract_umis.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "filter consensus reads",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/fgbio-0.5.0.jar",
                "FilterConsensusReads"
            ],
            "arguments": [
                "--output",
                {
                    "valueFrom": "$(runtime.outdir)/consensus_filtered.bam"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/dna-alignment"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--input"
                    },
                    "id": "#filter_consensus.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "prefix": "--max-base-error-rate"
                    },
                    "id": "#filter_consensus.cwl/max_base_error_rate"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "prefix": "--max-no-call-fraction"
                    },
                    "id": "#filter_consensus.cwl/max_no_call_fraction"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "prefix": "--max-read-error-rate"
                    },
                    "id": "#filter_consensus.cwl/max_read_error_rate"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "--min-base-quality"
                    },
                    "id": "#filter_consensus.cwl/min_base_quality"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "int"
                    },
                    "inputBinding": {
                        "prefix": "--min-reads"
                    },
                    "id": "#filter_consensus.cwl/min_reads"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--ref"
                    },
                    "id": "#filter_consensus.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "consensus_filtered.bam"
                    },
                    "id": "#filter_consensus.cwl/filtered_bam"
                }
            ],
            "id": "#filter_consensus.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "group reads by umi",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/fgbio-0.5.0.jar",
                "GroupReadsByUmi"
            ],
            "arguments": [
                "--strategy",
                "paired",
                "--assign-tag",
                "MI",
                "--raw-tag",
                "RX",
                "--min-map-q",
                "10",
                "--edits",
                "1",
                "--output",
                {
                    "valueFrom": "$(runtime.outdir)/umi_grouped.bam"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/dna-alignment"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--input"
                    },
                    "id": "#group_reads.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "umi_grouped.bam"
                    },
                    "id": "#group_reads.cwl/grouped_bam"
                }
            ],
            "id": "#group_reads.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "samtools index",
            "arguments": [
                "cp",
                "$(inputs.bam.path)",
                "$(runtime.outdir)/$(inputs.bam.basename)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "/opt/samtools/bin/samtools",
                "index",
                "$(inputs.bam.path)",
                "$(runtime.outdir)/$(inputs.bam.basename).bai",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "ln",
                "-s",
                "$(inputs.bam.basename).bai",
                "$(runtime.outdir)/$(inputs.bam.nameroot).bai"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/samtools-cwl:1.0.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#index_bam.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai",
                        "^.bai"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.bam.basename)"
                    },
                    "id": "#index_bam.cwl/indexed_bam"
                }
            ],
            "id": "#index_bam.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "fastq to bam",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/picard/picard.jar",
                "MarkIlluminaAdapters"
            ],
            "arguments": [
                "OUTPUT=",
                {
                    "valueFrom": "$(runtime.outdir)/marked.bam"
                },
                "METRICS=",
                {
                    "valueFrom": "$(runtime.outdir)/adapter_metrics.txt"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/dna-alignment"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "INPUT=",
                        "position": 1
                    },
                    "id": "#mark_illumina_adapters.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "marked.bam"
                    },
                    "id": "#mark_illumina_adapters.cwl/marked_bam"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "adapter_metrics.txt"
                    },
                    "id": "#mark_illumina_adapters.cwl/metrics"
                }
            ],
            "id": "#mark_illumina_adapters.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Sambamba: merge",
            "baseCommand": [
                "/usr/bin/sambamba_merge"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000,
                    "coresMin": 4
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/bisulfite"
                }
            ],
            "arguments": [
                "$(runtime.cores)",
                "$(runtime.outdir)/merged.bam"
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#merge_bams.cwl/bams"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "outputBinding": {
                        "glob": "merged.bam"
                    },
                    "id": "#merge_bams.cwl/merged_bam"
                }
            ],
            "id": "#merge_bams.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "umi realignment",
            "baseCommand": [
                "/bin/bash",
                "/usr/bin/umi_realignment.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000,
                    "coresMin": 8
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/dna-alignment"
                }
            ],
            "arguments": [
                {
                    "position": 3,
                    "valueFrom": "$(runtime.cores)"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#realign.cwl/bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#realign.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "outputBinding": {
                        "glob": "realigned.bam"
                    },
                    "id": "#realign.cwl/consensus_aligned_bam"
                }
            ],
            "id": "#realign.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "samtools flagstat",
            "baseCommand": [
                "/opt/samtools/bin/samtools",
                "flagstat"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/samtools-cwl:1.0.0"
                }
            ],
            "stdout": "$(inputs.bam.basename).flagstat",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#samtools_flagstat.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#samtools_flagstat.cwl/flagstats",
                    "outputBinding": {
                        "glob": "$(inputs.bam.basename).flagstat"
                    }
                }
            ],
            "id": "#samtools_flagstat.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "SelectVariants (GATK 3.6)",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "SelectVariants"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/gatk-cwl:3.6.0"
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.output_vcf_basename).vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--excludeFiltered",
                        "position": 4
                    },
                    "id": "#select_variants.cwl/exclude_filtered"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-L",
                        "position": 3
                    },
                    "id": "#select_variants.cwl/interval_list"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "select_variants",
                    "id": "#select_variants.cwl/output_vcf_basename"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#select_variants.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#select_variants.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.output_vcf_basename).vcf.gz"
                    },
                    "id": "#select_variants.cwl/filtered_vcf"
                }
            ],
            "id": "#select_variants.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "umi alignment",
            "baseCommand": [
                "/bin/bash",
                "/usr/bin/umi_alignment.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000,
                    "coresMin": 8
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/dna-alignment"
                }
            ],
            "arguments": [
                {
                    "position": 3,
                    "valueFrom": "$(runtime.cores)"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#umi_align.cwl/bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#umi_align.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "outputBinding": {
                        "glob": "aligned.bam"
                    },
                    "id": "#umi_align.cwl/aligned_bam"
                }
            ],
            "id": "#umi_align.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "verify BAM ID",
            "baseCommand": "/usr/local/bin/verifyBamID",
            "arguments": [
                "--out",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.bam.nameroot).VerifyBamId"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/verify_bam_id-cwl:1.1.3"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--bam"
                    },
                    "id": "#verify_bam_id.cwl/bam"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--vcf"
                    },
                    "id": "#verify_bam_id.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot).VerifyBamId.depthSM"
                    },
                    "id": "#verify_bam_id.cwl/verify_bam_id_depth"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot).VerifyBamId.selfSM"
                    },
                    "id": "#verify_bam_id.cwl/verify_bam_id_metrics"
                }
            ],
            "id": "#verify_bam_id.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
